@@ -15,6 +15,8 @@ logger = logging.getLogger(__name__)
 
 
 class Assembly():
+    """Assembly class
+    """
 
     def __init__(self, bdbag_dir, assembly):
         self._bdbag_dir = bdbag_dir
@@ -29,9 +31,8 @@ class Assembly():
         return self._assembly.accession
 
     def assembly_report(self):
-        '''
-        Assumes there is only one assembly report in the data catalog
-        '''
+        """Assumes there is only one assembly report in the data catalog
+        """
         for assembly_report_file in self._files_of_type(catalog_pb2.File.ASSEMBLY_REPORT):
             with open(os.path.join(self._bdbag_dir, 'data', assembly_report_file)) as fh:
                 raw_data = json.dumps(yaml.safe_load(fh.read()))
@@ -40,13 +41,13 @@ class Assembly():
 
     def fastas(self):
         for fasta_file in self._files_of_type(catalog_pb2.File.FASTA):
-            with open(os.path.join(self._bdbag_dir, 'data', fasta_file), "rt") as handle:
+            with open(os.path.join(self._bdbag_dir, 'data', fasta_file), 'rt') as handle:
                 for record in FastaIterator(handle):
                     yield record
 
-    def gff3s(self, filter=None):
+    def gff3s(self, filt=None):
         for gff3_file in self._files_of_type(catalog_pb2.File.GFF3):
-            if filter and filter in gff3_file or not filter:
+            if filt and filt in gff3_file or not filt:
                 yield os.path.join(self._bdbag_dir, 'data', gff3_file)
 
     def sequences(self):
@@ -55,16 +56,18 @@ class Assembly():
             # TODO: Awful hack b/c the catalog doesn't pair gff with fna
             m = re.search('chromosome (\\d+)', defline)
             if not m:
-                filter = 'genomic_MT'
+                filt = 'genomic_MT'
             else:
-                filter = f'genomic_{m.group(1)}'
+                filt = f'genomic_{m.group(1)}'
             gff3s = []
-            for gff3 in self.gff3s(filter=filter):
+            for gff3 in self.gff3s(filt=filt):
                 gff3s.append(gff3)
             yield Sequence(self.assembly_report(), sequence, gff3s[0])
 
 
 class BioDataset():
+    """BioDataset class
+    """
 
     def __init__(self, bdbag_dir):
         self._bdbag_dir = bdbag_dir
